home | help
WHOIS(1)		     General Commands Manual			WHOIS(1)

NAME
     whois -- Internet domain name and network number directory service

SYNOPSIS
     whois [-aAbdgiIklmQrR6] [-c country-code | -h host] [-p port] name ...

DESCRIPTION
     The  whois  utility looks up records in the databases maintained by several
     Network Information Centers (NICs).

     The options are as follows:

     -a      Use the American Registry for Internet Numbers (ARIN) database.  It
	     contains network numbers used in those parts of the  world  covered
	     neither by APNIC nor by RIPE.

	     (Hint:  All point of contact handles in the ARIN whois database end
	     with "-ARIN".)

     -A      Use the Asia/Pacific Network Information Center  (APNIC)  database.
	     It  contains  network  numbers  used  in  East Asia, Australia, New
	     Zealand, and the Pacific islands.

     -b      Use the Network Abuse  Clearinghouse  database.   It  contains  ad-
	     dresses  to  which network abuse should be reported, indexed by do-
	     main name.

     -c country-code
	     This is the equivalent of using the -h option with an  argument  of
	     "country-code.whois-servers.net".

     -d      Use  the  US Department of Defense database.  It contains points of
	     contact for subdomains of .MIL.

     -g      Use the US non-military federal government database, which contains
	     points of contact for subdomains of .GOV.

     -h host
	     Use the specified host instead of the default  variant.   Either  a
	     host name or an IP address may be specified.

	     By  default whois constructs the name of a whois server to use from
	     the top-level domain (TLD) of the supplied (single)  argument,  and
	     appending ".whois-servers.net".  This effectively allows a suitable
	     whois  server  to	be  selected automatically for a large number of
	     TLDs.

	     In the event that an IP address is specified, the whois server will
	     default to the American Registry for Internet Numbers (ARIN).  If a
	     query to ARIN references APNIC, LACNIC, or RIPE, that  server  will
	     be queried also, provided that the -Q option is not specified.

	     If  the  query  is not a domain name or IP address, whois will fall
	     back to whois.crsnic.net.

     -i      Use  the  Network	 Solutions   Registry	for   Internet	 Numbers
	     (whois.networksolutions.com) database.  It contains network numbers
	     and  domain  contact  information	for most of .COM, .NET, .ORG and
	     .EDU domains.

	     NOTE!  The registration of these domains is now done by a number of
	     independent and competing registrars and this database holds no in-
	     formation on the domains registered  by  organizations  other  than
	     Network  Solutions,  Inc.	 Also,	note  that the InterNIC database
	     (whois.internic.net) is no longer	handled  by  Network  Solutions,
	     Inc.  For details, see http://www.internic.net/.

	     (Hint:  Contact  information, identified by the term handle, can be
	     looked up by prefixing "handle " to the NIC handle in the query.)

     -I      Use the Internet Assigned Numbers Authority  (IANA)  database.   It
	     contains network information for top-level domains.

     -k      Use  the  National  Internet  Development Agency of Korea's (KRNIC)
	     database.	It contains network numbers and domain contact	informa-
	     tion for Korea.

     -l      Use  the  Latin American and Caribbean IP address Regional Registry
	     (LACNIC) database.  It contains network numbers  used  in	much  of
	     Latin America and the Caribbean.

     -m      Use  the Route Arbiter Database (RADB) database.  It contains route
	     policy specifications for a large number of operators' networks.

     -p port
	     Connect to the whois server on port.  If this option is not  speci-
	     fied, whois defaults to port 43.

     -Q      Do  a  quick  lookup.   This  means  that whois will not attempt to
	     lookup the name in  the  authoritative  whois  server  (if  one  is
	     listed).	This  option  has no effect when combined with any other
	     options.

     -r      Use the R'eseaux IP Europ'eens (RIPE) database.  It  contains  net-
	     work numbers and domain contact information for Europe.

     -R      Use the Russia Network Information Center (RIPN) database.  It con-
	     tains network numbers and domain contact information for subdomains
	     of .RU.  This option is deprecated; use the -c option with an argu-
	     ment of "RU" instead.

     -6      Use the IPv6 Resource Center (6bone) database.  It contains network
	     names and addresses for the IPv6 network.

     The  operands  specified to whois are treated independently and may be used
     as queries on different whois servers.

EXAMPLES
     Most types of data, such as domain names and IP addresses, can be	used  as
     arguments	to  whois without any options, and whois will choose the correct
     whois server to query.  Some exceptions, where whois will not  be	able  to
     handle data correctly, are detailed below.

     To obtain contact information about an administrator located in the Russian
     TLD domain "RU", use the -c option as shown in the following example, where
     CONTACT-ID is substituted with the actual contact identifier.

	   whois -c RU CONTACT-ID

     (Note:  This  example  is	specific  to the TLD "RU", but other TLDs can be
     queried by using a similar syntax.)

     The following example demonstrates how to obtain information about an  IPv6
     address or hostname using the -6 option, which directs the query to 6bone.

	   whois -6 IPv6-IP-Address

     The following example demonstrates how to query a whois server using a non-
     standard	port,	where	"query-data"   is   the  query	to  be	sent  to
     "whois.example.com" on port "rwhois" (written numerically as 4321).

	   whois -h whois.example.com -p rwhois query-data

SEE ALSO
     Ken Harrenstien and Vic White, NICNAME/WHOIS, 1 March 1982, RFC 812.

HISTORY
     The whois command appeared in 4.3BSD.

FreeBSD 5.4			December 11, 2004			WHOIS(1)

home | help